![Installation and Usage](https://raw.githubusercontent.com/dmkskn/polka_curses/master/images/install_and_usage.gif)

## Installation

Use `pip` to install the program (Python 3.7 is required):

```bash
pip install polka-curses
```

Doesn't work in Windows!

## Usage

To run the program, write `polka`.
